${app_name} • Nuvola Apps Runtime [![CircleCI](https://circleci.com/gh/tiliado/nuvola-app-${app_id_dashed}/tree/master.svg?style=svg)](https://circleci.com/gh/tiliado/nuvola-app-${app_id_dashed}/tree/master)
=================================

Integration of ${app_name} into your linux desktop via
[Nuvola Apps Runtime](https://github.com/tiliado/nuvolaruntime).

Support
-------

Follow [Bug reporting guidelines](https://github.com/tiliado/nuvolaruntime/wiki/Bug-Reporting-Guidelines).

Installation
------------

Install the [genuine cross-distribution flatpak packages](https://nuvola.tiliado.eu/app/${app_id}/).

Building
--------

This project uses [Nuvola SDK](https://github.com/tiliado/nuvolasdk#create-new-project). Please refer to
the [Build a Project Using Nuvola SDK](https://github.com/tiliado/nuvolasdk#build-a-project-using-nuvola-sdk)
page in order to obtain information about dependencies and installation instructions.

Change log
----------

See [CHANGELOG.md](./CHANGELOG.md).

Contributing
------------

See [CONTRIBUTING.md](./CONTRIBUTING.md).

Copyright
---------

  - `src/icon*.svg`
    + Copyright 2011 Alexander King <alexanderddking@gmail.com>
    + Copyright 2011 Arturo Torres Sánchez <arturo.ilhuitemoc@gmail.com>
    + License: [CC-BY-3.0](./LICENSE-CC-BY.txt)

  - Other files:
    + Copyright ${year} ${maintainer_name} <${maintainer_mail}>
    + License: [2-Clause BSD-license](./LICENSE-BSD.txt)
